@@ -1,7 +1,7 @@
 /*******************************************************************************
  ngx_http_h264_streaming_module.c - An Nginx module for streaming Quicktime/MPEG4 files.
 
- Copyright (C) 2008-2021 CodeShop B.V.
+ Copyright (C) 2008-2022 CodeShop B.V.
 
  For licensing see the LICENSE file
 ******************************************************************************/
@@ -844,8 +844,8 @@ static ngx_int_t ngx_streaming_handler(ngx_http_request_t *r)
 
   if(slcf->s3_secret_key.data && slcf->s3_access_key.data)
   {
-    context->secret_key_ = (char const*)slcf->s3_secret_key.data;
-    context->access_key_ = (char const*)slcf->s3_access_key.data;
+    context->s3_secret_key_ = (char const*)slcf->s3_secret_key.data;
+    context->s3_access_key_ = (char const*)slcf->s3_access_key.data;
     if(slcf->s3_region.data)
     {
       context->s3_region_ = (char const*)slcf->s3_region.data;
